@@ -17,6 +17,7 @@
 from typing import Optional, Tuple
 
 from absl.testing import absltest
+from absl.testing import parameterized
 from acme import environment_loop
 from acme import specs
 from acme.agents.jax import actors
@@ -25,6 +26,7 @@ from acme.jax import variable_utils
 from acme.testing import fakes
 import dm_env
 import haiku as hk
+import jax
 import jax.numpy as jnp
 import numpy as np
 
@@ -40,19 +42,26 @@ def _make_fake_env() -> dm_env.Environment:
   return fakes.Environment(env_spec, episode_length=10)
 
 
-class ActorTest(absltest.TestCase):
+class ActorTest(parameterized.TestCase):
 
-  def test_feedforward(self):
+  @parameterized.named_parameters(
+      ('policy', False),
+      ('policy_with_extras', True))
+  def test_feedforward(self, has_extras):
     environment = _make_fake_env()
     env_spec = specs.make_environment_spec(environment)
 
     def policy(inputs: jnp.ndarray):
-      return hk.Sequential([
+      action_values = hk.Sequential([
           hk.Flatten(),
           hk.Linear(env_spec.actions.num_values),
-          lambda x: jnp.argmax(x, axis=-1),
       ])(
           inputs)
+      action = jnp.argmax(action_values, axis=-1)
+      if has_extras:
+        return action, (action_values,)
+      else:
+        return action
 
     policy = hk.transform(policy, apply_rng=True)
 
@@ -64,7 +73,8 @@ class ActorTest(absltest.TestCase):
     variable_client = variable_utils.VariableClient(variable_source, 'policy')
 
     actor = actors.FeedForwardActor(
-        policy.apply, rng=hk.PRNGSequence(1), variable_client=variable_client)
+        policy.apply, random_key=jax.random.PRNGKey(1),
+        variable_client=variable_client, has_extras=has_extras)
 
     loop = environment_loop.EnvironmentLoop(environment, actor)
     loop.run(20)
@@ -74,9 +84,12 @@ def _transform_without_rng(f):
   return hk.without_apply_rng(hk.transform(f, apply_rng=True))
 
 
-class RecurrentActorTest(absltest.TestCase):
+class RecurrentActorTest(parameterized.TestCase):
 
-  def test_recurrent(self):
+  @parameterized.named_parameters(
+      ('policy', False),
+      ('policy_with_extras', True))
+  def test_recurrent(self, has_extras):
     environment = _make_fake_env()
     env_spec = specs.make_environment_spec(environment)
     output_size = env_spec.actions.num_values
@@ -85,16 +98,16 @@ class RecurrentActorTest(absltest.TestCase):
 
     @_transform_without_rng
     def network(inputs: jnp.ndarray, state: hk.LSTMState):
-      return hk.DeepRNN([lambda x: jnp.reshape(x, [-1]),
+      return hk.DeepRNN([hk.Reshape([-1], preserve_dims=1),
                          hk.LSTM(output_size)])(inputs, state)
 
     @_transform_without_rng
     def initial_state(batch_size: Optional[int] = None):
-      network = hk.DeepRNN([lambda x: jnp.reshape(x, [-1]),
+      network = hk.DeepRNN([hk.Reshape([-1], preserve_dims=1),
                             hk.LSTM(output_size)])
       return network.initial_state(batch_size)
 
-    initial_state = initial_state.apply(initial_state.init(next(rng)))
+    initial_state = initial_state.apply(initial_state.init(next(rng)), 1)
     params = network.init(next(rng), obs, initial_state)
 
     def policy(
@@ -105,13 +118,18 @@ class RecurrentActorTest(absltest.TestCase):
     ) -> Tuple[jnp.ndarray, hk.LSTMState]:
       del key  # Unused for test-case deterministic policy.
       action_values, core_state = network.apply(params, observation, core_state)
-      return jnp.argmax(action_values, axis=-1), core_state
+      actions = jnp.argmax(action_values, axis=-1)
+      if has_extras:
+        return (actions, (action_values,)), core_state
+      else:
+        return actions, core_state
 
     variable_source = fakes.VariableSource(params)
     variable_client = variable_utils.VariableClient(variable_source, 'policy')
 
     actor = actors.RecurrentActor(
-        policy, hk.PRNGSequence(1), initial_state, variable_client)
+        policy, jax.random.PRNGKey(1), initial_state, variable_client,
+        has_extras=has_extras)
 
     loop = environment_loop.EnvironmentLoop(environment, actor)
     loop.run(20)
