@@ -15,8 +15,11 @@
 
 """Implementation of a behavior cloning (BC) agent."""
 
-from acme.agents.jax.bc.learning import BCLearner
+from acme.agents.jax.bc import pretraining
+from acme.agents.jax.bc.learning import make_bc_learner_core
+from acme.agents.jax.bc.learning import TrainingState
 from acme.agents.jax.bc.losses import logp
+from acme.agents.jax.bc.losses import Loss
 from acme.agents.jax.bc.losses import mse
 from acme.agents.jax.bc.losses import peerbc
 from acme.agents.jax.bc.losses import rcal
