@@ -18,6 +18,7 @@
 import time
 from typing import Dict, Iterator, List, NamedTuple, Optional, Sequence, Tuple
 
+from absl import logging
 import acme
 from acme import specs
 from acme.agents.jax.impala import types
@@ -58,14 +59,19 @@ class IMPALALearner(acme.Learner):
       entropy_cost: float = 0.,
       baseline_cost: float = 1.,
       max_abs_reward: float = np.inf,
-      counter: counting.Counter = None,
-      logger: loggers.Logger = None,
+      counter: Optional[counting.Counter] = None,
+      logger: Optional[loggers.Logger] = None,
       devices: Optional[Sequence[jax.xla.Device]] = None,
       prefetch_size: int = 2,
       num_prefetch_threads: Optional[int] = None,
   ):
 
     local_devices = jax.local_devices()
+    process_id = jax.process_index()
+    logging.info('Learner process id: %s. Devices passed: %s', process_id,
+                 devices)
+    logging.info('Learner process id: %s. Local devices from JAX API: %s',
+                 process_id, local_devices)
     self._devices = devices or local_devices
     self._local_devices = [d for d in self._devices if d in local_devices]
 
@@ -95,6 +101,8 @@ class IMPALALearner(acme.Learner):
 
       metrics = {
           'loss': loss_value,
+          'param_norm': optax.global_norm(new_params),
+          'param_updates_norm': optax.global_norm(updates),
       }
 
       new_state = TrainingState(params=new_params, opt_state=new_opt_state)
