@@ -14,10 +14,19 @@
 # limitations under the License.
 
 """Some types/assumptions used in the IMPALA agent."""
+from typing import Callable
 
+from acme.jax import networks
+import haiku as hk
 import jax.numpy as jnp
 
 
 # Only simple observations & discrete action spaces for now.
 Observation = jnp.ndarray
 Action = int
+PolicyValueInitFn = Callable[[networks.PRNGKey, Observation, hk.LSTMState],
+                             networks.Params]
+PolicyValueFn = Callable[[networks.Params, Observation, hk.LSTMState],
+                         networks.LSTMOutputs]
+RecurrentStateInitFn = Callable[[networks.PRNGKey], networks.Params]
+RecurrentStateFn = Callable[[networks.Params], hk.LSTMState]
