@@ -16,7 +16,7 @@
 """DQN learner implementation."""
 
 import time
-from typing import Dict, List
+from typing import Dict, List, Optional, Union
 
 import acme
 from acme import types
@@ -51,11 +51,11 @@ class DQNLearner(acme.Learner, tf2_savers.TFSaveable):
       target_update_period: int,
       dataset: tf.data.Dataset,
       huber_loss_parameter: float = 1.,
-      replay_client: reverb.TFClient = None,
-      counter: counting.Counter = None,
-      logger: loggers.Logger = None,
+      replay_client: Optional[Union[reverb.Client, reverb.TFClient]] = None,
+      counter: Optional[counting.Counter] = None,
+      logger: Optional[loggers.Logger] = None,
       checkpoint: bool = True,
-      max_gradient_norm: float = None,
+      max_gradient_norm: Optional[float] = None,
   ):
     """Initializes the learner.
 
@@ -78,6 +78,15 @@ class DQNLearner(acme.Learner, tf2_savers.TFSaveable):
       max_gradient_norm: used for gradient clipping.
     """
 
+    # TODO(mwhoffman): stop allowing replay_client to be passed as a TFClient.
+    # This is just here for backwards compatability for agents which reuse this
+    # Learner and still pass a TFClient instance.
+    if isinstance(replay_client, reverb.TFClient):
+      # TODO(b/170419518): open source pytype does not understand this
+      # isinstance() check because it does not have a way of getting precise
+      # type information for pip-installed packages.
+      replay_client = reverb.Client(replay_client._server_address)  # pytype: disable=attribute-error
+
     # Internalise agent components (replay buffer, networks, optimizer).
     # TODO(b/155086959): Fix type stubs and remove.
     self._iterator = iter(dataset)  # pytype: disable=wrong-arg-types
@@ -86,6 +95,11 @@ class DQNLearner(acme.Learner, tf2_savers.TFSaveable):
     self._optimizer = snt.optimizers.Adam(learning_rate)
     self._replay_client = replay_client
 
+    # Make sure to initialize the optimizer so that its variables (e.g. the Adam
+    # moments) are included in the state returned by the learner (which can then
+    # be checkpointed and restored).
+    self._optimizer._initialize(network.trainable_variables)  # pylint: disable= protected-access
+
     # Internalise the hyperparameters.
     self._discount = discount
     self._target_update_period = target_update_period
@@ -155,11 +169,8 @@ class DQNLearner(acme.Learner, tf2_savers.TFSaveable):
     gradients, _ = tf.clip_by_global_norm(gradients, self._max_gradient_norm)
     self._optimizer.apply(gradients, self._network.trainable_variables)
 
-    # Update the priorities in the replay buffer.
-    if self._replay_client:
-      priorities = tf.cast(tf.abs(extra.td_error), tf.float64)
-      self._replay_client.update_priorities(
-          table=adders.DEFAULT_PRIORITY_TABLE, keys=keys, priorities=priorities)
+    # Get the priorities that we'll use to update.
+    priorities = tf.abs(extra.td_error)
 
     # Periodically update the target network.
     if tf.math.mod(self._num_steps, self._target_update_period) == 0:
@@ -171,6 +182,8 @@ class DQNLearner(acme.Learner, tf2_savers.TFSaveable):
     # Report loss & statistics for logging.
     fetches = {
         'loss': loss,
+        'keys': keys,
+        'priorities': priorities,
     }
 
     return fetches
@@ -179,6 +192,16 @@ class DQNLearner(acme.Learner, tf2_savers.TFSaveable):
     # Do a batch of SGD.
     result = self._step()
 
+    # Get the keys and priorities.
+    keys = result.pop('keys')
+    priorities = result.pop('priorities')
+
+    # Update the priorities in the replay buffer.
+    if self._replay_client:
+      self._replay_client.mutate_priorities(
+          table=adders.DEFAULT_PRIORITY_TABLE,
+          updates=dict(zip(keys.numpy(), priorities.numpy())))
+
     # Compute elapsed time.
     timestamp = time.time()
     elapsed_time = timestamp - self._timestamp if self._timestamp else 0
