@@ -1,4 +1,3 @@
-# python3
 # Copyright 2018 DeepMind Technologies Limited. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -21,7 +20,6 @@ from typing import Any, Mapping
 import numpy as np
 import tree
 
-
 LoggingData = Mapping[str, Any]
 
 
@@ -32,6 +30,10 @@ class Logger(abc.ABC):
   def write(self, data: LoggingData) -> None:
     """Writes `data` to destination (file, terminal, database, etc)."""
 
+  @abc.abstractmethod
+  def close(self) -> None:
+    """Closes the logger, not expecting any further write."""
+
 
 class NoOpLogger(Logger):
   """Simple Logger which does nothing and outputs no logs.
@@ -43,6 +45,9 @@ class NoOpLogger(Logger):
   def write(self, data: LoggingData):
     pass
 
+  def close(self):
+    pass
+
 
 def tensor_to_numpy(value: Any):
   if hasattr(value, 'numpy'):
